@@ -34,7 +34,7 @@
 #include "vstr.h"
 #include "config.h"
 
-static char gp_title[] = "dvdspanky 1.0.2 - (C) 2007 Jeffrey Grembecki\n\n";
+static char gp_title[] = "dvdspanky 1.0.3 - (C) 2007 Jeffrey Grembecki\n\n";
 static char gp_licence[] =
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -64,10 +64,9 @@ static char gp_help[] =
 "-b, --border           automatic black border [off]\n"
 "-B, --clip             clips edges to fit aspect [off]\n"
 "-c, --channels=CHANS   number of audio channels [auto] {1 - 5}\n"
-"-f, --filters=FILTERS  specify additional transcode filters [none]\n"
+"-f, --filters=FILTERS  specify transcode filters [none]\n"
 "-g, --gain=GAIN        multiply volume by GAIN [off/1.0]\n"
 "-G, --gamma=GAMMA      set gamma, < 1.0 is brighter, > is darker [1.0]\n"
-"-F, --frameadjust      interlace video for frame-rate conversion [off] *\n"
 "-h, --help             this help text\n"
 "-H, --hcrop=PIXELS     as above [off]\n"
 "-i, --input=FILE       input file\n"
@@ -126,7 +125,7 @@ static struct option gp_longopts[] =
 	{"verbose", 0, 0, 'v'},
 };
 
-static char gp_shortopts[] = "012a:AbBc:f:Fg:G:hH:i:ILmnNo:OpPr:R:s:TvV:";
+static char gp_shortopts[] = "012a:AbBc:f:Fg:G:hH:i:ILmMnNo:OpPr:R:s:TvV:";
 
 static pcre *gp_idregex = NULL;
 static pcre *gp_transregex = NULL;
@@ -286,7 +285,7 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 	if(options & SPANK_DOUBLEFPS)
 		vs_cat(p_video, " -J doublefps");
 	if(options & SPANK_NEWFPS)
-		vs_cat(p_video, " -M 0 -J ivtc,32detect=force_mode=3,decimate");
+		vs_cat(p_video, " -J modfps=clonetype=1");
 	if(options & SPANK_FIXNTSC)
 		vs_cat(p_video, " -M 2 -J ivtc,32detect=force_mode=5,decimate --hard_fps");
 
@@ -778,7 +777,7 @@ int cb_default(const char *p_string, void *p_options)
 		return 0;
 
 	/* output le shiz */
-	pprint(ML_VERBOSE, "?", "%s %s\n", (char*)p_options, p_string);
+	pprint(ML_VERBOSE, (char*)p_options, "%s\n", p_string);
 
 	return 0;
 }
@@ -813,12 +812,10 @@ int forkit(forkitcallback callback, void *p_options, const char *p_path, const c
 		pp_cmdopts[i] = &p_cmdline[start];
 		if(p_cmdline[pos] == 0)
 		{
-			/* fprintf(stderr, "  [debug-end] %s\n", &p_cmdline[start]); */
 			pp_cmdopts[i + 1] = 0;
 			break;
 		}
 		p_cmdline[pos] = 0;
-		/* fprintf(stderr, "  [debug-add] %s\n", &p_cmdline[start]); */
 		pos++;
 		start = pos;
 	}
@@ -936,6 +933,8 @@ int main(int argc, char **argv)
 	int options = 0;
 	video_t invid, outvid;
 
+	p_filters[0] = 0;
+
 	/* clear video data */
 	memset(&invid, '\0', sizeof(video_t));
 	memset(&outvid, '\0', sizeof(video_t));
@@ -1017,7 +1016,7 @@ int main(int argc, char **argv)
 				strncpy(p_filters, optarg, sizeof(p_filters) - 1);
 				break;
 			case 'F':
-				options |= SPANK_NEWFPS;
+				/* frameadjust, now automatic */
 				break;
 			case 'g':
 				outvid.volume = atof(optarg);
@@ -1174,7 +1173,14 @@ int main(int argc, char **argv)
 		"mplayer %s -identify -frames 0 -ao null -vo null", invid.p_filename);
 	forkitf(cb_tcprobe, &invid, TCPROBE_BIN, "tcprobe -i %s", invid.p_filename);
 	if(!invid.feedback) /* if tcprobe unable to detect, flag use of mplayer for input */
+	{
+		if(invid.p_vcodec[0] == 0)
+		{
+			printerror("unknown input format. do you have the codec installed?");
+			exit(1);
+		}
 		options |= SPANK_MPLAYER;
+	}
 
 	/* set audio bitrate / codec and scale */
 	strcpy(outvid.p_acodec, "AC3");
@@ -1285,20 +1291,20 @@ int main(int argc, char **argv)
 	/* set fps */
 	if(vidmode == 'p' && invid.fps == 25)
 	{
-		options &= 0xffff ^ SPANK_NEWFPS;
 		outvid.fps = 25;
 	}
 	else if(vidmode =='n' && (invid.fps == 23.976 || invid.fps == 29.97))
 	{
-		options &= 0xffff ^ SPANK_NEWFPS;
 		outvid.fps = invid.fps;
 	}
 	else if(vidmode == 'p')
 	{
+		options |= SPANK_NEWFPS;
 		outvid.fps = 25;
 	}
 	else
 	{
+		options |= SPANK_NEWFPS;
 		outvid.fps = 23.976;
 	}
 
